@@ -11,6 +11,9 @@ fi
 if test -x /usr/bin/automake-1.7 ; then
 	ver="-1.7"
 fi
+if test -x /usr/bin/automake-1.8 ; then
+	ver="-1.8"
+fi
 
 # The VERSION file defines our versioning
 PQXXVERSION=`grep '\<PQXXVERSION\>' VERSION | sed -e 's/^[[:space:]A-Z_]*//' | sed -e 's/[[:space:]]*#.*$//'`
@@ -25,12 +28,11 @@ sed -e "s/@PQXXVERSION@/$PQXXVERSION/g" configure.ac.in >configure.ac
 # Generate win32/test.mak (adding carriage returns to make it MS-DOS format)
 ./tools/maketestvcmak.pl test | sed -e 's/$/\r/' >win32/test.mak
 
-aclocal${ver}
-
 # Don't run autoheader to avoid overwriting customized config.h.in!
 # autoheader
 
 libtoolize --force --automake --copy
+aclocal${ver} -I .
 automake${ver} --verbose --add-missing --copy
 autoconf
 
