@@ -7,7 +7,7 @@
  *      definitions for the pqxx::cachedresult class and support classes.
  *   pqxx::cachedresult is a lazy-fetching, transparently-cached result set
  *
- * Copyright (c) 2001-2003, Jeroen T. Vermeulen <jtv@xs4all.nl>
+ * Copyright (c) 2001-2004, Jeroen T. Vermeulen <jtv@xs4all.nl>
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this mistake,
@@ -131,7 +131,13 @@ private:
    * operation.
    */
   template<typename ISOLATIONTAG>
-    static inline void error_permitted_isolation_level(ISOLATIONTAG) throw();
+    static inline void error_permitted_isolation_level(ISOLATIONTAG) throw ();
+
+#if defined(__SUNPRO_CC)
+  // Incorrect, but needed to compile with Sun CC
+  template<> static void 
+    error_permitted_level(isolation_traits<serializable>) throw() {}
+#endif	// __SUNPRO_CC
 #else
   // Incorrect, but needed to compile with Visual C++ 7
   template<> static inline void
