@@ -7,7 +7,7 @@
  *      definition of the pqxx::Cursor class.
  *   pqxx::Cursor represents a database cursor.
  *
- * Copyright (c) 2001-2003, Jeroen T. Vermeulen <jtv@xs4all.nl>
+ * Copyright (c) 2001-2004, Jeroen T. Vermeulen <jtv@xs4all.nl>
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this mistake,
@@ -22,7 +22,7 @@
 #include "pqxx/transaction_base.h"
 #include "pqxx/util.h"
 
-/* Methods tested in eg. self-test program test1 are marked with "//[t1]"
+/* Methods tested in eg. self-test program test001 are marked with "//[t1]"
  */
 
 namespace pqxx
@@ -66,6 +66,8 @@ class result;
 
 class PQXX_LIBEXPORT Cursor
 {
+  enum { dist_next=1 };
+
 public:
   typedef result::size_type size_type;
 
@@ -94,7 +96,7 @@ public:
     Cursor(TRANSACTION &T,
            const char Query[], 
 	   const PGSTD::string &BaseName="cur",
-	   size_type Count=NEXT()) :					//[t3]
+	   size_type Count=dist_next) :					//[t3]
       m_Trans(T),
       m_Name(),
       m_Count(Count),
@@ -141,7 +143,7 @@ public:
   template<typename TRANSACTION>
     Cursor(TRANSACTION &T,
            const result::field &Name,
-	   size_type Count=NEXT()) :					//[t45]
+	   size_type Count=dist_next) :					//[t45]
       m_Trans(T),
       m_Name(Name.c_str()),
       m_Count(Count),
@@ -189,7 +191,7 @@ public:
   static size_type ALL() throw ();					//[t3]
 
   /// Constant: "next fetch/move should cover just the next row."
-  static size_type NEXT() throw () { return 1; }			//[t19]
+  static size_type NEXT() throw () { return dist_next; }		//[t19]
 
   /// Constant: "next fetch/move should go back one row."
   static size_type PRIOR() throw () { return -1; }			//[t19]
@@ -262,6 +264,12 @@ private:
    */
   template<typename ISOLATIONTAG> 
     static inline void error_permitted_isolation_level(ISOLATIONTAG) throw();
+
+#if defined(__SUNPRO_CC)
+  // Incorrect, but needed to compile with Sun CC
+  template<> static void 
+    error_permitted_level(isolation_traits<serializable>) throw() {}
+#endif	// __SUNPRO_CC
 #else
   // Incorrect, but needed to compile with Visual C++ 7
   template<> static inline void 
@@ -284,7 +292,7 @@ template<> inline void
 Cursor::error_permitted_isolation_level(isolation_traits<serializable>) throw ()
 	{}
 
-}
+} // namespace pqxx
 
 #endif
 
