@@ -6,7 +6,7 @@
  *   DESCRIPTION
  *      Compiler deficiency workarounds for libpqxx clients
  *
- * Copyright (c) 2002-2003, Jeroen T. Vermeulen <jtv@xs4all.nl>
+ * Copyright (c) 2002-2004, Jeroen T. Vermeulen <jtv@xs4all.nl>
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this mistake,
@@ -29,6 +29,15 @@ typedef long ptrdiff_t;
 #ifdef PQXX_BROKEN_ITERATOR
 #include <cstddef>
 #include <cstdlib>
+/// Alias for the std namespace to accomodate nonstandard C++ implementations
+/** The PGSTD name will almost always be defined to mean std.  The exception are
+ * third-party C++ standard library implementations that use a different 
+ * namespace to avoid conflicts with the standard library that came with the
+ * compiler.
+ *
+ * Some definitions that appear missing in the standard library of the host
+ * system may be added to get libpqxx working.
+ */
 namespace PGSTD
 {
 /// Work around lacking iterator template definition in <iterator>
@@ -78,6 +87,16 @@ template<> struct char_traits<unsigned char>
 }
 #endif
 
+// Workarounds for SUN Workshop 6
+#if defined(__SUNPRO_CC)
+#if __SUNPRO_CC_COMPAT < 5
+#error "This compiler version is not capable of building libpqxx."
+#endif	// __SUNPRO_CC_COMPAT < 5
+
+#define PQXX_BROKEN_MEMBER_TEMPLATE_DEFAULT_ARG
+
+#endif	// __SUNPRO_CC
+
 // Workarounds for Windows
 #ifdef _WIN32
 
@@ -89,6 +108,7 @@ template<> struct char_traits<unsigned char>
 // Workarounds for Visual C++.NET (2003 version does seem to work)
 #if _MSC_VER < 1310
 #define PQXX_WORKAROUND_VC7
+#undef PQXX_HAVE_REVERSE_ITERATOR
 #define PQXX_NO_PARTIAL_CLASS_TEMPLATE_SPECIALISATION
 #define PQXX_TYPENAME
 #endif	// _MSC_VER < 1310
