@@ -7,7 +7,7 @@
  *      Implementation of the Large Objects interface
  *   Allows access to large objects directly, or though I/O streams
  *
- * Copyright (c) 2003, Jeroen T. Vermeulen <jtv@xs4all.nl>
+ * Copyright (c) 2003-2004, Jeroen T. Vermeulen <jtv@xs4all.nl>
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this mistake,
@@ -36,7 +36,7 @@ inline int StdModeToPQMode(ios::openmode mode)
 }
 
 
-inline int StdDirToPQDir(ios::seekdir dir)
+inline int StdDirToPQDir(ios::seekdir dir) throw ()
 {
   int pqdir;
   switch (dir)
@@ -59,7 +59,7 @@ inline int StdDirToPQDir(ios::seekdir dir)
 } // namespace
 
 
-pqxx::largeobject::largeobject() :
+pqxx::largeobject::largeobject() throw () :
   m_ID(oid_none)
 {
 }
@@ -85,7 +85,7 @@ pqxx::largeobject::largeobject(dbtransaction &T, const string &File) :
 }
 
 
-pqxx::largeobject::largeobject(const largeobjectaccess &O) :
+pqxx::largeobject::largeobject(const largeobjectaccess &O) throw () :
   m_ID(O.id())
 {
 }
@@ -226,7 +226,7 @@ void pqxx::largeobjectaccess::open(openmode mode)
 }
 
 
-void pqxx::largeobjectaccess::close()
+void pqxx::largeobjectaccess::close() throw ()
 {
   if (m_fd >= 0) lo_close(RawConnection(), m_fd);
 }
@@ -237,3 +237,9 @@ string pqxx::largeobjectaccess::Reason() const
   return (m_fd == -1) ? "No object opened" : largeobject::Reason();
 }
 
+
+void pqxx::largeobjectaccess::process_notice(const string &s) throw ()
+{
+  m_Trans.process_notice(s);
+}
+
