@@ -7,7 +7,7 @@
  *      implementation of the pqxx::robusttransaction class.
  *   pqxx::robusttransaction is a slower but safer transaction class
  *
- * Copyright (c) 2002-2003, Jeroen T. Vermeulen <jtv@xs4all.nl>
+ * Copyright (c) 2002-2004, Jeroen T. Vermeulen <jtv@xs4all.nl>
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this mistake,
@@ -31,9 +31,12 @@ using namespace PGSTD;
 #define SQL_ROLLBACK_WORK 	"ROLLBACK"
 
 pqxx::basic_robusttransaction::basic_robusttransaction(connection_base &C, 
-	const PGSTD::string &IsolationLevel,
+	const string &IsolationLevel,
 	const string &TName) :
-  dbtransaction(C, IsolationLevel, TName),
+  dbtransaction(C, 
+      IsolationLevel, 
+      TName, 
+      "robusttransaction<"+IsolationLevel+">"),
   m_ID(oid_none),
   m_LogTable()
 {
