@@ -1,6 +1,8 @@
 #include <algorithm>
 #include <cstdio>
+#include <functional>
 #include <iostream>
+#include <iterator>
 
 #include <pqxx/pqxx>
 
@@ -10,6 +12,16 @@ using namespace pqxx;
 namespace
 {
 
+#ifndef PQXX_HAVE_COUNT_IF
+template<typename IN, typename P> inline long count_if(IN first, IN last, P p)
+{
+  long cnt;
+  for (cnt=0; first!=last; ++first) cnt += p(*first);
+  return cnt;
+}
+#endif
+
+
 // Adds first element of each tuple it receives to a container
 template<typename CONTAINER> struct Add
 {
@@ -55,8 +67,8 @@ struct CountGreaterSmaller : unary_function<result::tuple, void>
   {
     // Count number of entries with key greater/smaller than first row's key
     // using std::count_if<>()
-    const int Greater = count_if(R.begin(), R.end(), bind2nd(Cmp(Key),T)),
-              Smaller = count_if(R.begin(), R.end(), bind1st(Cmp(Key),T));
+    const long Greater = count_if(R.begin(), R.end(), bind2nd(Cmp(Key),T)),
+               Smaller = count_if(R.begin(), R.end(), bind1st(Cmp(Key),T));
 
     cout << "'" << T[Key] << "': " 
          << Greater << " greater, "
